@@ -75,6 +75,7 @@ static int create_metadata_block_groups(struct btrfs_root *root, int mixed,
 	int ret;
 
 	trans = btrfs_start_transaction(root, 1);
+	BUG_ON(IS_ERR(trans));
 	bytes_used = btrfs_super_bytes_used(fs_info->super_copy);
 
 	root->fs_info->system_allocs = 1;
@@ -435,6 +436,14 @@ static int add_directory_items(struct btrfs_trans_handle *trans,
 		filetype = BTRFS_FT_REG_FILE;
 	if (S_ISLNK(st->st_mode))
 		filetype = BTRFS_FT_SYMLINK;
+	if (S_ISSOCK(st->st_mode))
+		filetype = BTRFS_FT_SOCK;
+	if (S_ISCHR(st->st_mode))
+		filetype = BTRFS_FT_CHRDEV;
+	if (S_ISBLK(st->st_mode))
+		filetype = BTRFS_FT_BLKDEV;
+	if (S_ISFIFO(st->st_mode))
+		filetype = BTRFS_FT_FIFO;
 
 	ret = btrfs_insert_dir_item(trans, root, name, name_len,
 				    parent_inum, &location,
@@ -719,7 +728,7 @@ again:
 	 * keep our extent size at 1MB max, this makes it easier to work inside
 	 * the tiny block groups created during mkfs
 	 */
-	cur_bytes = min(total_bytes, 1024ULL * 1024);
+	cur_bytes = min(total_bytes, (u64)SZ_1M);
 	ret = btrfs_reserve_extent(trans, root, cur_bytes, 0, 0, (u64)-1,
 				   &key, 1);
 	if (ret)
@@ -992,7 +1001,7 @@ static int create_chunks(struct btrfs_trans_handle *trans,
 	u64 chunk_size;
 	u64 meta_type = BTRFS_BLOCK_GROUP_METADATA;
 	u64 data_type = BTRFS_BLOCK_GROUP_DATA;
-	u64 minimum_data_chunk_size = 8 * 1024 * 1024;
+	u64 minimum_data_chunk_size = SZ_8M;
 	u64 i;
 	int ret;
 
@@ -1047,6 +1056,7 @@ static int make_image(const char *source_dir, struct btrfs_root *root)
 	INIT_LIST_HEAD(&dir_head.list);
 
 	trans = btrfs_start_transaction(root, 1);
+	BUG_ON(IS_ERR(trans));
 	ret = traverse_directory(trans, root, source_dir, &dir_head);
 	if (ret) {
 		error("unable to traverse directory %s: %d", source_dir, ret);
@@ -1095,9 +1105,9 @@ static u64 size_sourcedir(const char *dir_name, u64 sectorsize,
 	u64 dir_size = 0;
 	u64 total_size = 0;
 	int ret;
-	u64 default_chunk_size = 8 * 1024 * 1024;	/* 8MB */
-	u64 allocated_meta_size = 8 * 1024 * 1024;	/* 8MB */
-	u64 allocated_total_size = 20 * 1024 * 1024;	/* 20MB */
+	u64 default_chunk_size = SZ_8M;
+	u64 allocated_meta_size = SZ_8M;
+	u64 allocated_total_size = 20 * SZ_1M;	/* 20MB */
 	u64 num_of_meta_chunks = 0;
 	u64 num_of_data_chunks = 0;
 	u64 num_of_allocated_meta_chunks =
@@ -1325,6 +1335,7 @@ static int cleanup_temp_chunks(struct btrfs_fs_info *fs_info,
 
 	btrfs_init_path(&path);
 	trans = btrfs_start_transaction(root, 1);
+	BUG_ON(IS_ERR(trans));
 
 	key.objectid = 0;
 	key.type = BTRFS_BLOCK_GROUP_ITEM_KEY;
@@ -1758,7 +1769,7 @@ int main(int argc, char **argv)
 	}
 
 	trans = btrfs_start_transaction(root, 1);
-	if (!trans) {
+	if (IS_ERR(trans)) {
 		error("failed to start transaction");
 		goto error;
 	}
@@ -1782,7 +1793,7 @@ int main(int argc, char **argv)
 	}
 
 	trans = btrfs_start_transaction(root, 1);
-	if (!trans) {
+	if (IS_ERR(trans)) {
 		error("failed to start transaction");
 		goto error;
 	}
@@ -1860,6 +1871,7 @@ raid_groups:
 
 	if (source_dir_set) {
 		trans = btrfs_start_transaction(root, 1);
+		BUG_ON(IS_ERR(trans));
 		ret = create_chunks(trans, root,
 				    num_of_meta_chunks, size_of_data,
 				    &allocation);
