@@ -4,41 +4,14 @@
 
 source $TOP/tests/common
 
-check_prereq btrfs-show-super
 check_prereq mkfs.btrfs
 check_prereq btrfs
 
-ndevs=4
-declare -a devs
-dev1=
-
 setup_root_helper
 
-prepare_devices()
-{
-	for i in `seq $ndevs`; do
-		touch img$i
-		chmod a+rw img$i
-		truncate -s0 img$i
-		truncate -s2g img$i
-		devs[$i]=`run_check_stdout $SUDO_HELPER losetup --find --show img$i`
-	done
-}
-
-cleanup_devices()
-{
-	for dev in ${devs[@]}; do
-		run_check $SUDO_HELPER losetup -d $dev
-	done
-	for i in `seq $ndevs`; do
-		truncate -s0 img$i
-	done
-	run_check $SUDO_HELPER losetup --list
-}
-
 test_get_info()
 {
-	run_check $TOP/btrfs-show-super $dev1
+	run_check $SUDO_HELPER $TOP/btrfs inspect-internal dump-super $dev1
 	run_check $SUDO_HELPER $TOP/btrfs check $dev1
 	run_check $SUDO_HELPER mount $dev1 $TEST_MNT
 	run_check $TOP/btrfs filesystem df $TEST_MNT
@@ -59,12 +32,13 @@ test_mkfs_single()
 }
 test_mkfs_multi()
 {
-	test_do_mkfs $@ ${devs[@]}
+	test_do_mkfs $@ ${loopdevs[@]}
 	test_get_info
 }
 
-prepare_devices
-dev1=${devs[1]}
+setup_loopdevs 4
+prepare_loopdevs
+dev1=${loopdevs[1]}
 
 test_mkfs_single
 test_mkfs_single  -d  single  -m  single
@@ -90,4 +64,4 @@ test_mkfs_multi   -d  raid6   -m  raid6   --mixed
 test_mkfs_multi   -d  dup     -m  dup
 test_mkfs_multi   -d  dup     -m  dup     --mixed
 
-cleanup_devices
+cleanup_loopdevs
